/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.placeholder.fileresolver;

import java.io.File;

import org.tinygroup.fileresolver.impl.AbstractFileProcessor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.placeholder.filewriter.ZipTools;
import org.tinygroup.vfs.FileObject;

/**
 * war文件处理
 * 
 * @author zhaozhen
 * 
 */
public class WarFileProcessor extends AbstractFileProcessor {

	private static final String SCHEPA_HEAD = "///";

	/**
	 * 处理所有后缀为.war的文件
	 */
	public boolean isMatch(FileObject fileObject) {
		if (fileObject.getFileName().endsWith(".war")) {
			return true;
		}
		return false;
	}

	/**
	 * 解压war文件
	 */
	public void process() {
		for (FileObject fileObject : fileObjects) {
			String warPath = fileObject.getAbsolutePath();
			warPath = warPath.substring(warPath.indexOf(SCHEPA_HEAD)
					+ SCHEPA_HEAD.length());
			String warFileName = warPath
					.substring(warPath.lastIndexOf("/") + 1);
			warPath = warPath.substring(0, warPath.lastIndexOf(".war"));
			logger.logMessage(LogLevel.INFO, "正在解压war[{0}],解压到[{1}]",
					fileObject.getAbsolutePath(), warPath);
			// 创建目录
			File tempFile = new File(warPath);
			tempFile.mkdirs();
			// 解压文件
			ZipTools.execCommand("jar xf ../" + warFileName, null, new File(
					warPath));
		}
	}

	/**
	 * 删除解压的临时目录，并重新打包
	 */
	public void removeWarFiles() {
		for (FileObject fileObject : fileObjects) {
			String warPath = fileObject.getAbsolutePath();
			warPath = warPath.substring(warPath.indexOf(SCHEPA_HEAD) + 3);
			String warFileName = warPath
					.substring(warPath.lastIndexOf("/") + 1);
			warPath = warPath.substring(0, warPath.lastIndexOf(".war"));
			File tempFile = new File(warPath);
			if (tempFile.exists()) {
				logger.logMessage(LogLevel.INFO, "正在重新打包war[{0}],删除临时目录[{1}]",
						fileObject.getAbsolutePath(), tempFile);
				// 重新打包war
				ZipTools.execCommand("jar uvf ../" + warFileName + " *.*",
						null, new File(warPath));
				// 删除临时
				deleteDirectory(tempFile);
			}
		}
		// 清除processFiles
		fileObjects.clear();
	}

	/**
	 * 用于删除目录
	 * 
	 * @param path
	 * @return
	 */
	public static boolean deleteDirectory(File path) {
		if (path.exists()) {
			File[] files = path.listFiles();
			for (int i = 0; i < files.length; i++) {
				if (files[i].isDirectory()) {
					deleteDirectory(files[i]);
				} else {
					files[i].delete();
				}
			}
		}
		return (path.delete());
	}

	public void clean() {
	}


}
